# DataRetrievalStatus


## Enum

* `PENDING_LOAD` (value: `'pending_load'`)

* `LOADED` (value: `'loaded'`)

* `EXPIRED` (value: `'expired'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


